@@ -54,7 +54,7 @@ class AccessLogMiddleware(BaseHTTPMiddleware):
       path = urlparse(str(request.url)).path
       end = perf_counter()
       elapsed = round((end - start) * 1000, 2)
-      logging.info(f'[{response.status_code}] {request.method} {path} [{}ms]')
+      logging.info(f'[{response.status_code}] {request.method} {path} [{elapsed}ms]')
     return response
 
 
